"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _loaderUtils = _interopRequireDefault(require("loader-utils"));

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _importResource = require("../import-resource");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const importReadModel = ({
  resolveConfig,
  isClient
}, resourceQuery) => {
  if (!/^\?/.test(resourceQuery)) {
    throw new Error(`Resource $resolve.readModel should be retrieved with resource query`);
  }

  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.readModels`);
  }

  const {
    readModelName,
    onlyProjection
  } = _loaderUtils.default.parseQuery(resourceQuery);

  let readModel = null;
  let index = -1;

  for (let currentIndex = 0; currentIndex < resolveConfig.readModels.length; currentIndex++) {
    if (resolveConfig.readModels[currentIndex].name === readModelName) {
      readModel = resolveConfig.readModels[currentIndex];
      index = currentIndex;
    }
  }

  if (readModelName == null || readModel == null || index < 0) {
    throw new Error(`Read-model ${readModelName} does not exist (readModels[${index}])`);
  }

  const imports = [];
  const constants = [];
  const exports = [];

  if ((0, _declare_runtime_env.checkRuntimeEnv)(readModel.name)) {
    throw new Error(`${_constants.message.clientEnvError}.readModels[${index}].name`);
  }

  constants.push(`const name_${index} = ${JSON.stringify(readModel.name)}`);

  if ((0, _declare_runtime_env.checkRuntimeEnv)(readModel.connectorName)) {
    throw new Error(`${_constants.message.clientEnvError}.readModels[${index}].connectorName`);
  }

  constants.push(`const connectorName_${index} = ${JSON.stringify(readModel.connectorName)}`);

  if (!onlyProjection) {
    (0, _importResource.importResource)({
      resourceName: `resolvers_${index}`,
      resourceValue: readModel.resolvers,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      imports,
      constants
    });
  }

  exports.push(`const readModel = {`, `  name: name_${index}`);

  if (!onlyProjection) {
    exports.push(`, resolvers: resolvers_${index}`);
  }

  exports.push(`, connectorName: connectorName_${index}`);
  (0, _importResource.importResource)({
    resourceName: `projection_${index}`,
    resourceValue: readModel.projection,
    runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
    importMode: _constants.RESOURCE_ANY,
    instanceMode: _constants.IMPORT_INSTANCE,
    ...(!onlyProjection ? {
      calculateHash: 'resolve-read-model-projection-hash'
    } : {}),
    imports,
    constants
  });
  exports.push(`, projection: projection_${index}`);

  if (!onlyProjection) {
    exports.push(`, invariantHash: projection_${index}_hash`);
    (0, _importResource.importResource)({
      resourceName: `encryption_${index}`,
      resourceValue: readModel.encryption,
      runtimeMode: _constants.RUNTIME_ENV_NOWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: {
        package: '@resolve-js/runtime-base',
        import: 'disabledEncryption'
      },
      imports,
      constants
    });
    exports.push(`, encryption: encryption_${index}`);
  }

  exports.push(`}`, ``);
  exports.push(`export default readModel`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

var _default = importReadModel;
exports.default = _default;
//# sourceMappingURL=$resolve.readModel.js.map