"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _get_webpack_client_configs = _interopRequireDefault(require("./get_webpack_client_configs"));

var _get_webpack_common_configs = _interopRequireDefault(require("./get_webpack_common_configs"));

var _get_webpack_alias = _interopRequireDefault(require("./get_webpack_alias"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getWebpackConfigs = async ({
  resolveConfig,
  nodeModulesByAssembly,
  adjustWebpackConfigs
}) => {
  const alias = (0, _get_webpack_alias.default)();
  const webpackClientConfigs = (0, _get_webpack_client_configs.default)({
    resolveConfig,
    alias,
    nodeModulesByAssembly
  });
  const webpackCommonConfigs = (0, _get_webpack_common_configs.default)({
    resolveConfig,
    alias,
    nodeModulesByAssembly
  });
  const configs = [...webpackClientConfigs, ...webpackCommonConfigs];

  if (typeof adjustWebpackConfigs === 'function') {
    await adjustWebpackConfigs(configs, {
      alias,
      nodeModulesByAssembly
    });
  }

  for (const config of configs) {
    // .webpack.js should have precedence over other extensions
    const extensions = config.resolve.extensions;

    if (Array.isArray(extensions) && extensions.length > 0) {
      const index = extensions.findIndex(ext => ext === '.webpack.js');

      if (index >= 0) {
        extensions.splice(index, 1);
      }

      if (extensions[0] !== '.webpack.js') {
        config.resolve.extensions = ['.webpack.js', ...extensions];
      }
    }
  }

  return configs;
};

var _default = getWebpackConfigs;
exports.default = _default;
//# sourceMappingURL=get_webpack_configs.js.map